Workspace upgrade to 9.4.0.129 fails with communityserver install (packages version)

Hi
Thanks for your reply

With step 2, it seems to go further, but still fails

Here is the terminal log with explanations

terminal3.log (59.0 KB)

Hello @sosfc
It seems that one issue has been resolved, but a new one has appeared, and it is related to the Nginx service.

Please run the following commands and share the output with us:

sudo nginx -t
sudo service nginx restart; echo "exit code: $?"

systemctl status nginx.service
journalctl -xeu nginx.service --no-pager | tail -50
tail -50 /var/log/nginx/error.log

ss -tlnp | grep -E ':80 |:443 '

ls -la /etc/nginx/sites-enabled/ /etc/nginx/includes/

Hi

Thanks for your reply.
Doing as listed above, you will find the result in the terminal4.log file.
nginx seems to fail due to le line 19 which is {{DOCKER_APP_SUBNET}} 0;

It’s not a docker version, it’s a package version and docker is not installed

Thanks,

Fernand

terminal4.log (32.7 KB)

It seems that this folder /etc/nginx/sites-available/onlyoffice contains a copy of ssl template which is preventing the update process. Please remove it and install the correct package:

sudo rm -rf /etc/nginx/sites-available/onlyoffice
sudo apt-get install --reinstall -o Dpkg::Options::="--force-confmiss" onlyoffice-communityserver

Please let us know the result.

Hi

Thanks for your reply. Here is the result :

root@workspace:/home/sosfc# sudo apt-get install --reinstall -o Dpkg::Options::=“–force-confmiss” onlyoffice-communityserver
Lecture des listes de paquets… Fait
Construction de l’arbre des dépendances… Fait
Lecture des informations d’état… Fait
0 mis à jour, 0 nouvellement installés, 1 réinstallés, 0 à enlever et 122 non mis à jour.
1 partiellement installés ou enlevés.
Après cette opération, 0 o d’espace disque supplémentaires seront utilisés.
E: Internal Error, No file name for onlyoffice-communityserver:amd64
root@workspace:/home/sosfc#

Have I missed something ?

Thanks

Let’s check that you can get this package. Please run:

sudo apt-get update
apt-cache policy onlyoffice-communityserver

Please show us the output result.

Hi,
This is the result :

root@workspace:/home/sosfc# apt-get update
Atteint :1 Index of /packages/debian/ buster InRelease
Réception de :2 Index of /debian-security bookworm-security InRelease [34,8 kB]
Atteint :3 https://artifacts.elastic.co/packages/7.x/apt stable InRelease
Atteint :4 Index of /debian bookworm InRelease
Atteint :5 http://download.onlyoffice.com/repo/debian squeeze InRelease
Atteint :6 Index of /232905/apt/debian bookworm InRelease
Réception de :7 Index of /debian bookworm-updates InRelease [55,4 kB]
Atteint :8 https://d2nlctn12v279m.cloudfront.net/repo/mono/ubuntu focal InRelease
Atteint :9 https://deb.nodesource.com/node_16.x nodistro InRelease
Réception de :10 Index of /debian-security bookworm-security/main Sources [220 kB]
Atteint :11 Pain itself, and of. bookworm InRelease
Réception de :12 Index of /debian-security bookworm-security/main amd64 Packages [318 kB]
Réception de :13 Index of /debian-security bookworm-security/main Translation-en [194 kB]
Ign :14 Index of /debian/12/prod/ bookworm InRelease
Ign :15 https://download.mono-project.com/repo/debian stable-buster/snapshots/6.8.0.123 InRelease
Ign :14 Index of /debian/12/prod/ bookworm InRelease
Ign :15 https://download.mono-project.com/repo/debian stable-buster/snapshots/6.8.0.123 InRelease
Ign :14 Index of /debian/12/prod/ bookworm InRelease
Ign :15 https://download.mono-project.com/repo/debian stable-buster/snapshots/6.8.0.123 InRelease
Err :14 Index of /debian/12/prod/ bookworm InRelease
Connexion à packages.microsoft.com: 443 (192.168.1.240) impossible. - connect (111: Connexion refusée)
Err :15 https://download.mono-project.com/repo/debian stable-buster/snapshots/6.8.0.123 InRelease
Connexion à download.mono-project.com: 443 (192.168.1.240) impossible. - connect (111: Connexion refusée)
822 ko réceptionnés en 17s (47,5 ko/s)
Lecture des listes de paquets… Fait
W: Impossible de récupérer https://packages.microsoft.com/debian/12/prod/dists/bookworm/InRelease Connexion à packages.microsoft.com: 443 (192.168.1.240) impossible. - connect (111: Connexion refusée)
W: Impossible de récupérer https://download.mono-project.com/repo/debian/dists/stable-buster/snapshots/6.8.0.123/InRelease Connexion à download.mono-project.com: 443 (192.168.1.240) impossible. - connect (111: Connexion refusée)
W: Le téléchargement de quelques fichiers d’index a échoué, ils ont été ignorés, ou les anciens ont été utilisés à la place.
root@workspace:/home/sosfc# apt-cache policy onlyoffice-communityserver
onlyoffice-communityserver:
Installé : 12.8.0.1971
Candidat : 12.8.0.1971
Table de version :
*** 12.8.0.1971 500
500 http://download.onlyoffice.com/repo/debian squeeze/main amd64 Packages
100 /var/lib/dpkg/status
root@workspace:/home/sosfc#

I think I may have found the issue. I compared your command with mine:


It seems that your command (the second line) contains different quotation marks and is missing a dash. Could you please try again and copy and paste my example?

sudo rm -rf /etc/nginx/sites-available/onlyoffice
sudo apt-get install --reinstall -o Dpkg::Options::="--force-confmiss" onlyoffice-communityserver

I think I missed something
root@workspace:/home/sosfc# sudo apt-get install --reinstall -o Dpkg::Options::=”–force-confmiss” onlyoffice-communityserver
Lecture des listes de paquets… Fait
Construction de l’arbre des dépendances… Fait
Lecture des informations d’état… Fait
0 mis à jour, 0 nouvellement installés, 1 réinstallés, 0 à enlever et 124 non mis à jour.
1 partiellement installés ou enlevés.
Après cette opération, 0 o d’espace disque supplémentaires seront utilisés.
E: Internal Error, No file name for onlyoffice-communityserver:amd64
root@workspace:/home/sosfc#

Hello @sosfc
Something is going wrong on your server. You downloaded the package previously, so the current error is a bit confusing.
Please try the following steps to update the package indexes and clear the cache:

sudo apt-get clean
sudo rm -rf /var/lib/apt/lists/*
sudo apt-get update
sudo apt-get install --reinstall -o Dpkg::Options::="--force-confmiss" onlyoffice-communityserver

If the issue persists, please run the following commands to download the package:

sudo apt-get install --reinstall --download-only onlyoffice-communityserver
ls -la /var/cache/apt/archives/ | grep onlyoffice
sudo dpkg -i /var/cache/apt/archives/onlyoffice-communityserver_12.8.0.1971*.deb

If both steps fail, please show us the output of the following commands:

grep -r onlyoffice /etc/apt/sources.list /etc/apt/sources.list.d/ 2>/dev/null
apt-get update 2>&1 | tail -30

Hi, thanks for your reply.
It seems that you found the problem. The server does not want to download the onlyoffice-communityserver deb file

Hello @sosfc
Sorry for the late reply. Yes, it seems we have found the issue. Let’s try digging why the package isn’t being saved. Please show us the output result of these commands:

apt-config dump | grep -i Keep-Downloaded-Packages
find /var/cache/apt -name "onlyoffice-communityserver*.deb"
apt-get -o Debug::pkgAcquire::Worker=1 --reinstall --download-only install onlyoffice-communityserver

Hi

There is the result :

root@workspace:/home/sosfc# apt-config dump | grep -i Keep-Downloaded-Packages
Binary::apt::APT::Keep-Downloaded-Packages “0”;
root@workspace:/home/sosfc# find /var/cache/apt -name “onlyoffice-communityserver*.deb”
root@workspace:/home/sosfc# apt-get -o Debug::pkgAcquire::Worker=1 --reinstall --download-only install onlyoffice-communityserver
Lecture des listes de paquets… Fait
Construction de l’arbre des dépendances… Fait
Lecture des informations d’état… Fait
0 mis à jour, 0 nouvellement installés, 1 réinstallés, 0 à enlever et 132 non mis à jour.
1 partiellement installés ou enlevés.
Après cette opération, 0 o d’espace disque supplémentaires seront utilisés.
Téléchargement achevé et dans le mode téléchargement uniquement
root@workspace:/home/sosfc#

Thank you, please show me the output result of this command:

grep -r onlyoffice /etc/apt/sources.list /etc/apt/sources.list.d/ 2>/dev/null
apt-get update 2>&1 | tail -30

Hi Alexandre

Thanks for your reply.
Here is the result

root@workspace:/home/sosfc# grep -r onlyoffice /etc/apt/sources.list /etc/apt/sources.list.d/ 2>/dev/null
/etc/apt/sources.list.d/onlyoffice.list:deb [signed-by=/usr/share/keyrings/onlyoffice.gpg] http://download.onlyoffice.com/repo/debian squeeze main
root@workspace:/home/sosfc# apt-get update 2>&1 | tail -30
Atteint :1 http://download.onlyoffice.com/repo/debian squeeze InRelease
Atteint :2 Index of /debian bookworm InRelease
Réception de :3 Index of /debian-security bookworm-security InRelease [34,8 kB]
Atteint :4 https://artifacts.elastic.co/packages/7.x/apt stable InRelease
Réception de :5 Index of /debian bookworm-updates InRelease [55,4 kB]
Atteint :6 https://d2nlctn12v279m.cloudfront.net/repo/mono/ubuntu focal InRelease
Atteint :7 https://deb.nodesource.com/node_16.x nodistro InRelease
Réception de :8 Index of /debian-security bookworm-security/main Sources [221 kB]
Atteint :9 Index of /packages/debian/ buster InRelease
Réception de :10 Index of /232905/apt/debian bookworm InRelease [30,0 kB]
Atteint :11 Pain itself, and of. bookworm InRelease
Réception de :12 Index of /debian-security bookworm-security/main amd64 Packages [321 kB]
Atteint :13 https://download.mono-project.com/repo/debian stable-buster/snapshots/6.8.0.123 InRelease
Réception de :14 Index of /232905/apt/debian bookworm/mysql-tools amd64 Packages [4.168 B]
Réception de :15 Index of /debian-security bookworm-security/main Translation-en [197 kB]
Réception de :16 Index of /debian/12/prod/ bookworm InRelease [3.618 B]
Réception de :17 Index of /debian/12/prod/ bookworm/main arm64 Packages [131 kB]
Réception de :18 Index of /debian/12/prod/ bookworm/main amd64 Packages [243 kB]
Réception de :19 Index of /debian/12/prod/ bookworm/main armhf Packages [19,0 kB]
1.260 ko réceptionnés en 3s (479 ko/s)
Lecture des listes de paquets…
W: Distribution en conflit : https://download.mono-project.com/repo/debian stable-buster/snapshots/6.8.0.123 InRelease (stable-buster/snapshots/6.8.0.123 attendu, mais buster obtenu)
root@workspace:/home/sosfc#

Hello @sosfc
The more we investigated, the more I came to believe that there’s a local issue on the server. Please try clearing and rebuilding the package cache, it may help:

sudo apt-get clean
sudo rm -rf /var/lib/apt/lists/*
sudo apt-get update
sudo apt-get install --reinstall -o Dpkg::Options::="--force-confmiss" onlyoffice-communityserver

If that doesn’t help, please try the following:

wget http://download.onlyoffice.com/repo/debian/pool/main/o/onlyoffice-communityserver/onlyoffice-communityserver_12.8.0.1971_all.deb -O /tmp/onlyoffice-communityserver.deb
sudo apt install /tmp/onlyoffice-communityserver.deb -o Dpkg::Options::="--force-confmiss"

Please let us know the result.

Hello, hanks for your reply.
Here is the result (not ok) :

root@workspace:/home/sosfc# apt-get clean
root@workspace:/home/sosfc# rm -rf /var/lib/apt/list
listchanges.db lists/
root@workspace:/home/sosfc# rm -rf /var/lib/apt/lists/*
root@workspace:/home/sosfc# apt update
Réception de :1 http://download.onlyoffice.com/repo/debian squeeze InRelease [10,7 kB]
Réception de :2 http://download.onlyoffice.com/repo/debian squeeze/main amd64 Packages [49,3 kB]
Réception de :3 https://d2nlctn12v279m.cloudfront.net/repo/mono/ubuntu focal InRelease [7.518 B]
Réception de :4 Index of /debian-security bookworm-security InRelease [34,8 kB]
Réception de :5 Index of /debian bookworm InRelease [151 kB]
Réception de :6 Index of /packages/debian/ buster InRelease [3.601 B]
Réception de :7 https://artifacts.elastic.co/packages/7.x/apt stable InRelease [13,7 kB]
Réception de :8 https://deb.nodesource.com/node_16.x nodistro InRelease [12,1 kB]
Réception de :9 Index of /debian-security bookworm-security/non-free-firmware Sources [796 B]
Réception de :10 https://d2nlctn12v279m.cloudfront.net/repo/mono/ubuntu focal/main amd64 Packages [607 B]
Réception de :11 Index of /packages/debian/ buster/nginx amd64 Packages [24,8 kB]
Réception de :12 Index of /232905/apt/debian bookworm InRelease [30,0 kB]
Réception de :13 https://artifacts.elastic.co/packages/7.x/apt stable/main amd64 Packages [145 kB]
Réception de :14 Index of /debian-security bookworm-security/main Sources [236 kB]
Réception de :15 https://deb.nodesource.com/node_16.x nodistro/main amd64 Packages [7.462 B]
Réception de :16 Index of /debian bookworm-updates InRelease [55,4 kB]
Réception de :17 Pain itself, and of. bookworm InRelease [151 kB]
Réception de :18 Index of /debian bookworm/non-free-firmware Sources [7.152 B]
Réception de :19 Index of /debian-security bookworm-security/main amd64 Packages [326 kB]
Réception de :20 https://download.mono-project.com/repo/debian stable-buster/snapshots/6.8.0.123 InRelease [5.887 B]
Réception de :21 Index of /232905/apt/debian bookworm/mysql-8.0 Sources [964 B]
Réception de :22 Index of /debian-security bookworm-security/main Translation-en [202 kB]
Réception de :23 Index of /debian-security bookworm-security/non-free-firmware amd64 Packages [688 B]
Réception de :24 Index of /debian-security bookworm-security/non-free-firmware Translation-en [472 B]
Réception de :25 Index of /debian bookworm/main Sources [9.492 kB]
Réception de :26 Index of /232905/apt/debian bookworm/mysql-apt-config amd64 Packages [568 B]
Réception de :27 https://download.mono-project.com/repo/debian stable-buster/snapshots/6.8.0.123/main amd64 Packages [48,6 kB]
Réception de :28 Index of /232905/apt/debian bookworm/mysql-8.0 amd64 Packages [12,7 kB]
Réception de :29 Index of /debian/12/prod/ bookworm InRelease [3.618 B]
Réception de :30 Index of /232905/apt/debian bookworm/mysql-tools amd64 Packages [4.166 B]
Réception de :31 Index of /debian/12/prod/ bookworm/main armhf Packages [20,7 kB]
Réception de :32 Pain itself, and of. bookworm/contrib Sources [51,1 kB]
Réception de :33 Index of /debian/12/prod/ bookworm/main all Packages [576 B]
Réception de :34 Index of /debian/12/prod/ bookworm/main amd64 Packages [291 kB]
Réception de :35 Pain itself, and of. bookworm/main Sources [9.492 kB]
Réception de :36 Index of /debian/12/prod/ bookworm/main arm64 Packages [170 kB]
Réception de :37 Pain itself, and of. bookworm/main amd64 Packages [8.790 kB]
Réception de :38 Pain itself, and of. bookworm/main Translation-fr [2.728 kB]
Réception de :39 Pain itself, and of. bookworm/main Translation-en [6.107 kB]
Réception de :40 Pain itself, and of. bookworm/main amd64 DEP-11 Metadata [4.492 kB]
Réception de :41 Index of /debian bookworm/main amd64 Packages [8.790 kB]
Réception de :42 Pain itself, and of. bookworm/contrib amd64 Packages [53,5 kB]
Réception de :43 Pain itself, and of. bookworm/contrib Translation-en [48,4 kB]
Réception de :44 Pain itself, and of. bookworm/contrib amd64 DEP-11 Metadata [16,5 kB]
Réception de :45 Index of /debian bookworm/main Translation-en [6.107 kB]
Réception de :46 Index of /debian bookworm/main Translation-fr [2.728 kB]
Réception de :47 Index of /debian bookworm/main amd64 DEP-11 Metadata [4.492 kB]
Réception de :48 Index of /debian bookworm/non-free-firmware amd64 Packages [6.368 B]
Réception de :49 Index of /debian bookworm/non-free-firmware Translation-en [20,9 kB]
Réception de :50 Index of /debian bookworm/non-free-firmware amd64 DEP-11 Metadata [15,5 kB]
Réception de :51 Index of /debian bookworm-updates/main Sources [3.288 B]
Réception de :52 Index of /debian bookworm-updates/main amd64 Packages [6.924 B]
Réception de :53 Index of /debian bookworm-updates/main Translation-en [5.448 B]
65,5 Mo réceptionnés en 1min 51s (588 ko/s)
Lecture des listes de paquets… Fait
Construction de l’arbre des dépendances… Fait
Lecture des informations d’état… Fait
137 paquets peuvent être mis à jour. Exécutez « apt list --upgradable » pour les voir.
W: Distribution en conflit : https://download.mono-project.com/repo/debian stable-buster/snapshots/6.8.0.123 InRelease (stable-buster/snapshots/6.8.0.123 attendu, mais buster obtenu)
root@workspace:/home/sosfc# sudo apt-get install --reinstall -o Dpkg::Options::=“–force-confmiss” onlyoffice-communityserver
Lecture des listes de paquets… Fait
Construction de l’arbre des dépendances… Fait
Lecture des informations d’état… Fait
0 mis à jour, 0 nouvellement installés, 1 réinstallés, 0 à enlever et 137 non mis à jour.
1 partiellement installés ou enlevés.
Après cette opération, 0 o d’espace disque supplémentaires seront utilisés.
E: Internal Error, No file name for onlyoffice-communityserver:amd64
root@workspace:/home/sosfc# cd /tmp
root@workspace:/tmp# wget http://download.onlyoffice.com/repo/debian/pool/main/o/onlyoffice-communityserver/onlyoffice-communityserver_12.8.0.1971_all.deb -O /tmp/onlyoffice-communityserver.deb
sudo apt install /tmp/onlyoffice-communityserver.deb -o Dpkg::Options::=“–force-confmiss”
–2026-08-09 17:43:43-- http://download.onlyoffice.com/repo/debian/pool/main/o/onlyoffice-communityserver/onlyoffice-communityserver_12.8.0.1971_all.deb
Résolution de download.onlyoffice.com (download.onlyoffice.com)… 109.61.86.70, 2a02:6ea0:f900::3
Connexion à download.onlyoffice.com (download.onlyoffice.com)|109.61.86.70|:80… connecté.
requête HTTP transmise, en attente de la réponse… 200 OK
Taille : 803067940 (766M) [binary/octet-stream]
Sauvegarde en : « /tmp/onlyoffice-communityserver.deb »

/tmp/onlyoffice-communityserver.d 100%[==========================================================>] 765,87M 2,34MB/s ds 6m 20s

2026-08-09 17:50:02 (2,02 MB/s) — « /tmp/onlyoffice-communityserver.deb » sauvegardé [803067940/803067940]

Lecture des listes de paquets… Fait
Construction de l’arbre des dépendances… Fait
Lecture des informations d’état… Fait
Note : sélection de « onlyoffice-communityserver » au lieu de « /tmp/onlyoffice-communityserver.deb »
onlyoffice-communityserver est déjà la version la plus récente (12.8.0.1971).
0 mis à jour, 0 nouvellement installés, 0 à enlever et 137 non mis à jour.
1 partiellement installés ou enlevés.
Après cette opération, 0 o d’espace disque supplémentaires seront utilisés.
Souhaitez-vous continuer ? [O/n] n
Annulation.
root@workspace:/tmp# sudo apt install /tmp/onlyoffice-communityserver.deb -o Dpkg::Options::=“–force-confmiss”
Lecture des listes de paquets… Fait
Construction de l’arbre des dépendances… Fait
Lecture des informations d’état… Fait
Note : sélection de « onlyoffice-communityserver » au lieu de « /tmp/onlyoffice-communityserver.deb »
onlyoffice-communityserver est déjà la version la plus récente (12.8.0.1971).
0 mis à jour, 0 nouvellement installés, 0 à enlever et 137 non mis à jour.
1 partiellement installés ou enlevés.
Après cette opération, 0 o d’espace disque supplémentaires seront utilisés.
Souhaitez-vous continuer ? [O/n] o
Paramétrage de onlyoffice-communityserver (12.8.0.1971) …

  • . /usr/share/debconf/confmodule
    ++ ‘[’ ‘!’ ‘’ ‘]’
    ++ PERL_DL_NONLAZY=1
    ++ export PERL_DL_NONLAZY
    ++ ‘[’ ‘’ ‘]’
    ++ exec /usr/share/debconf/frontend /var/lib/dpkg/info/onlyoffice-communityserver.postinst configure 12.7.1.1942
  • . /usr/share/debconf/confmodule
    ++ ‘[’ ‘!’ 1 ‘]’
    ++ ‘[’ -z ‘’ ‘]’
    ++ exec
    ++ ‘[’ ‘’ ‘]’
    ++ exec
    ++ DEBCONF_REDIR=1
    ++ export DEBCONF_REDIR
  • DIR=/var/www/onlyoffice
  • LOG_DIR=/var/log/onlyoffice
  • APP_DATA_DIR=/var/www/onlyoffice/Data
    ++ dpkg -l elasticsearch
    ++ tail -n1
    ++ awk ‘{print $3}’
  • ELASTIC_SEARCH_VERSION=7.16.3
  • APP_INDEX_DIR=/var/www/onlyoffice/Data/Index/v7.16.3
  • APP_SERVICES_DIR=/var/www/onlyoffice/Services
  • OLD_VERSION=12.7.1.1942
  • NGINX_ROOT_DIR=/etc/nginx
  • CONFIG_DIR=/etc/onlyoffice/communityserver
  • DB_HOST=
  • DB_USER=
  • DB_PWD=
  • DB_NAME=
  • case “$1” in
  • cat /etc/passwd
  • grep -q onlyoffice:
  • cat /etc/group
  • grep -q nginx:
  • cat /etc/passwd
  • grep -q nginx:
  • usermod -aG onlyoffice,nginx onlyoffice
  • ‘[’ ‘!’ -z 12.7.1.1942 ‘]’
    ++ awk -F. ‘{ printf(“%d%03d%03d%03d”, $1,$2,$3,$4); }’
  • OLDER_PACKAGE_VERSION=120070011942
  • install_db
  • db_get onlyoffice-communityserver/db-host
  • _db_cmd ‘GET onlyoffice-communityserver/db-host’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/db-host’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=127.0.0.1
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DB_HOST=127.0.0.1
  • db_get onlyoffice-communityserver/db-user
  • _db_cmd ‘GET onlyoffice-communityserver/db-user’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/db-user’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=root
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DB_USER=root
  • db_get onlyoffice-communityserver/db-pwd
  • _db_cmd ‘GET onlyoffice-communityserver/db-pwd’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/db-pwd’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=P8oxD5LqytmN
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DB_PWD=P8oxD5LqytmN
  • db_get onlyoffice-communityserver/db-name
  • _db_cmd ‘GET onlyoffice-communityserver/db-name’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/db-name’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=onlyoffice
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DB_NAME=onlyoffice
  • MYSQL=‘mysql -h127.0.0.1 -uroot’
  • ‘[’ -n P8oxD5LqytmN ‘]’
  • MYSQL=‘mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN’
  • sed ‘s/#max_connections.*/max_connections = 1000/’ -i /etc/mysql/my.cnf
  • CNF_PATH=/etc/mysql/mysql.conf.d/mysqld.cnf
  • CNF_SERVICE_PATH=/lib/systemd/system/mysql.service
  • mysql -V
  • grep -q MariaDB
  • ‘[’ -e /etc/mysql/mysql.conf.d/mysqld.cnf ‘]’
  • grep -q ‘^sql_mode’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/sql_mode.*/sql_mode = ‘‘‘NO_ENGINE_SUBSTITUTION’’’/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^max_connections’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/max_connections.*/max_connections = 1000/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^group_concat_max_len’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/group_concat_max_len.*/group_concat_max_len = 2048/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^max_allowed_packet’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/max_allowed_packet.*/max_allowed_packet = 1048576000/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^character_set_server’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/character_set_server.*/character_set_server = utf8/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^collation_server’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/collation_server.*/collation_server = utf8_general_ci/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^interactive_timeout’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/interactive_timeout.*/interactive_timeout = 900/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^wait_timeout’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/wait_timeout.*/wait_timeout = 900/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • ‘[’ -e /lib/systemd/system/mysql.service ‘]’
  • grep -q ‘^LimitNOFILE’ /lib/systemd/system/mysql.service
  • sed ‘s/LimitNOFILE.*/LimitNOFILE = infinity/’ -i /lib/systemd/system/mysql.service
  • grep -q ‘^LimitMEMLOCK’ /lib/systemd/system/mysql.service
  • sed ‘s/LimitMEMLOCK.*/LimitMEMLOCK = infinity/’ -i /lib/systemd/system/mysql.service
  • systemctl daemon-reload
  • sed -i ‘/^default-authentication-plugin/d’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN -e ‘;’
    ++ mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN -e ‘SHOW VARIABLES LIKE ‘‘‘default_authentication_plugin’’’;’ -s
    ++ awk ‘{print $2}’
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • MYSQL_AUTHENTICATION_PLUGIN=caching_sha2_password
  • ‘[’ -n caching_sha2_password ‘]’
  • grep -q ‘^default-authentication-plugin’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘/[mysqld]/a default-authentication-plugin = caching_sha2_password’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • ‘[’ root = root ‘]’
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN -D mysql -e ‘ALTER USER ‘‘‘root’’’@’‘‘localhost’’’ IDENTIFIED WITH caching_sha2_passwor
    d BY ‘‘‘P8oxD5LqytmN’’’’
  • service mysql restart
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN -e ‘CREATE DATABASE IF NOT EXISTS onlyoffice CHARACTER SET utf8 COLLATE utf8_general_ci
    ;’
    mysql: [Warning] Using a password on the command line interface can be insecure.
    ++ mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN --silent --skip-column-names -e ‘SELECT COUNT(*) FROM information_schema.tables WHERE tabl
    e_schema=’‘‘onlyoffice’’‘’
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • DB_TABLES_COUNT=208
  • ‘[’ 208 -eq 0 ‘]’
    ++ ls /var/www/onlyoffice/Sql/onlyoffice.upgrade80.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade81.sql /var/www/onlyoffice/Sql/onlyo
    ffice.upgrade85.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade86.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade87.sql /var/www/onlyof
    fice/Sql/onlyoffice.upgrade88.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade890.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade892.sql
    /var/www/onlyoffice/Sql/onlyoffice.upgrade90.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade91.sql /var/www/onlyoffice/Sql/onlyoffice
    .upgrade950.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade952.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade960.sql /var/www/onlyoffi
    ce/Sql/onlyoffice.upgrade962.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade963.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev100.sql
    /var/www/onlyoffice/Sql/onlyoffice.upgradev105.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev110.sql /var/www/onlyoffice/Sql/onlyof
    fice.upgradev111.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev115.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev116.sql /var/www/o
    nlyoffice/Sql/onlyoffice.upgradev120.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev121.sql /var/www/onlyoffice/Sql/onlyoffice.upgrad
    ev125.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev126.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev127.sql /var/www/onlyoffice/S
    ql/onlyoffice.upgradev128.sql
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • grep -q client_max_body_size /etc/nginx/nginx.conf
  • sed -i ‘s/(client_max_body_size).*?;/\1 100m;/’ /etc/nginx/nginx.conf
  • ‘[’ ‘!’ -f /proc/net/if_inet6 ‘]’
  • apply_connection_string
  • binDirs=(“WebStudio” “ApiSystem” “Services/TeamLabSvc”)
  • ‘[’ 127.0.0.1 ‘!=’ localhost ‘]’
  • ‘[’ -d /var/www/onlyoffice/ ‘]’
  • for i in “${!binDirs[@]}”
  • find /var/www/onlyoffice/WebStudio -type f -name ‘.[cC]onfig’ -exec sed -i 's/connectionString=./connectionString=“Server=127.0.0
    .1;Database=onlyoffice;User ID=root;Password=P8oxD5LqytmN;Pooling=true;Character Set=utf8;AutoEnlist=false;SSL Mode=none;AllowPublicK
    eyRetrieval=true;Connection Timeout=30;Maximum Pool Size=300;” providerName=“MySql.Data.MySqlClient”/>/’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • find /var/www/onlyoffice/ApiSystem -type f -name ‘.[cC]onfig’ -exec sed -i 's/connectionString=./connectionString=“Server=127.0.0
    .1;Database=onlyoffice;User ID=root;Password=P8oxD5LqytmN;Pooling=true;Character Set=utf8;AutoEnlist=false;SSL Mode=none;AllowPublicK
    eyRetrieval=true;Connection Timeout=30;Maximum Pool Size=300;” providerName=“MySql.Data.MySqlClient”/>/’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • find /var/www/onlyoffice/Services/TeamLabSvc -type f -name ‘.[cC]onfig’ -exec sed -i 's/connectionString=./connectionString=“Serv
    er=127.0.0.1;Database=onlyoffice;User ID=root;Password=P8oxD5LqytmN;Pooling=true;Character Set=utf8;AutoEnlist=false;SSL Mode=none;Al
    lowPublicKeyRetrieval=true;Connection Timeout=30;Maximum Pool Size=300;” providerName=“MySql.Data.MySqlClient”/>/’ ‘{}’ ‘;’
  • find /var/www/onlyoffice/Services/ASC.UrlShortener/config -type f -name '.json’ -exec sed -i -e 's!(“host”:).,!\1 “127.0.0.1”,!
    ’ -e ‘s!(“user”:).,!\1 “root”,!’ -e 's!(“password”:).,!\1 “P8oxD5LqytmN”,!’ -e ‘s!(“database”:).*!\1 “onlyoffice”!’ ‘{}’ ‘;’
  • sed -i ‘s/Server=.*/Server=127.0.0.1;Port=3306;Database=onlyoffice;User ID=root;Password=P8oxD5LqytmN;Pooling=true;Character Set=ut
    f8;AutoEnlist=false;SSL Mode=none;AllowPublicKeyRetrieval=True;ConnectionReset=false",/g’ /etc/onlyoffice/communityserver/appsettings
    .production.json
  • apply_core_machinekey
  • db_get onlyoffice-communityserver/machinekey
  • _db_cmd ‘GET onlyoffice-communityserver/machinekey’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/machinekey’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=kAH2nodUYizf
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • ‘[’ ‘!’ -z 120070011942 ‘]’
  • CORE_MACHINEKEY=kAH2nodUYizf
  • ‘[’ -z kAH2nodUYizf ‘]’
  • true
  • sed ‘s^(machine_key)\s*=.*^\1 = kAH2nodUYizf^g’ -i /var/www/onlyoffice/Services/TeamLabSvc/radicale.config
  • binDirs=(“$DIR/ApiSystem/” “$DIR/WebStudio” “$DIR/controlpanel/www/config” “$APP_SERVICES_DIR” “$CONFIG_DIR”)
  • for i in “${!binDirs[@]}”
  • ‘[’ -d /var/www/onlyoffice/ApiSystem/ ‘]’
  • find /var/www/onlyoffice/ApiSystem/ -type f -name ‘.[cC]onfig’ -exec sed -i '/core.\machinekey/s_(value\s=\s*“)[^”]*"\1kAH2nod
    UYizf"
    ’ ‘{}’ ‘;’
  • find /var/www/onlyoffice/ApiSystem/ -type f -name ‘.json’ -exec sed -i 's_(“core.machinekey”:|“machinekey”:).,\1 “kAH2nodUYiz
    f”,
    ’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • ‘[’ -d /var/www/onlyoffice/WebStudio ‘]’
  • find /var/www/onlyoffice/WebStudio -type f -name ‘.[cC]onfig’ -exec sed -i '/core.\machinekey/s_(value\s=\s*“)[^”]*"\1kAH2nodU
    Yizf"
    ’ ‘{}’ ‘;’
  • find /var/www/onlyoffice/WebStudio -type f -name ‘.json’ -exec sed -i 's_(“core.machinekey”:|“machinekey”:).,\1 "kAH2nodUYizf
    ",
    ’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • ‘[’ -d /var/www/onlyoffice/controlpanel/www/config ‘]’
  • find /var/www/onlyoffice/controlpanel/www/config -type f -name ‘.[cC]onfig’ -exec sed -i '/core.\machinekey/s_(value\s=\s*“)[^”
    ]*"\1kAH2nodUYizf"’ ‘{}’ ‘;’
  • find /var/www/onlyoffice/controlpanel/www/config -type f -name ‘.json’ -exec sed -i 's_(“core.machinekey”:|“machinekey”:).,\1
    “kAH2nodUYizf”,
    ’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • ‘[’ -d /var/www/onlyoffice/Services ‘]’
  • find /var/www/onlyoffice/Services -type f -name ‘.[cC]onfig’ -exec sed -i '/core.\machinekey/s_(value\s=\s*“)[^”]*"\1kAH2nodUY
    izf"
    ’ ‘{}’ ‘;’
  • find /var/www/onlyoffice/Services -type f -name ‘.json’ -exec sed -i 's_(“core.machinekey”:|“machinekey”:).,\1 “kAH2nodUYizf”
    ,
    ’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • ‘[’ -d /etc/onlyoffice/communityserver ‘]’
  • find /etc/onlyoffice/communityserver -type f -name ‘.[cC]onfig’ -exec sed -i '/core.\machinekey/s_(value\s=\s*“)[^”]*"\1kAH2no
    dUYizf"
    ’ ‘{}’ ‘;’
  • find /etc/onlyoffice/communityserver -type f -name ‘.json’ -exec sed -i 's_(“core.machinekey”:|“machinekey”:).,\1 “kAH2nodUYi
    zf”,
    ’ ‘{}’ ‘;’
  • mkdir -p /etc/mono/registry/LocalMachine
  • mkdir -p /usr/share/.mono/keypairs
  • mkdir -p /var/log/onlyoffice
  • mkdir -p /var/www/onlyoffice/Data
  • mkdir -p /var/www/onlyoffice/DocumentServerData
  • mkdir -p /var/cache/nginx/onlyoffice
  • mkdir -p /var/run/onlyoffice
  • rm -dfr /tmp/onlyofficeAutoCleanUp /tmp/onlyoffice-communityserver.deb /tmp/onlyoffice-temp-aspnet-0
  • rm -dfr /var/run/onlyoffice/onlyofficeApiSystem.socket /var/run/onlyoffice/onlyoffice.socket
  • rm -dfr ‘/var/cache/nginx/onlyoffice/*’
  • mkdir -p -m 700 /var/www/onlyoffice/.config/.mono/keypairs
  • chown nginx:nginx -R /var/cache/nginx/onlyoffice
  • chown onlyoffice:nginx -R /var/run/onlyoffice
  • chmod g+s+w /var/run/onlyoffice
  • rm -f /etc/nginx/sites-enabled/default
  • rm -f /etc/nginx/sites-enabled/onlyoffice-apisystem
  • which apparmor_parser
    /usr/sbin/apparmor_parser
  • ‘[’ ‘!’ -f /etc/apparmor.d/disable/usr.sbin.mysqld ‘]’
  • ‘[’ -f /etc/apparmor.d/disable/ ‘]’
  • ‘[’ -d /etc/apport/blacklist.d ‘]’
    ++ python3 -c ‘import sys; print(sys.version_info.minor)’
  • ‘[’ -f /usr/lib/python3.11/EXTERNALLY-MANAGED ‘]’
  • pip_packages+=(“setuptools<82” “radicale==3.0.5”)
  • for pkg in requests importlib-metadata
  • dpkg -l python3-requests
  • for pkg in requests importlib-metadata
  • dpkg -l python3-importlib-metadata
  • export PIP_ROOT_USER_ACTION=ignore
  • PIP_ROOT_USER_ACTION=ignore
  • python3 -m pip install --upgrade --ignore-installed ‘setuptools<82’ radicale==3.0.5 /var/www/onlyoffice/Tools/radicale/plugins/app_
    auth_plugin/. /var/www/onlyoffice/Tools/radicale/plugins/app_store_plugin/. /var/www/onlyoffice/Tools/radicale/plugins/app_rights_plu
    gin/.
    Processing /var/www/onlyoffice/Tools/radicale/plugins/app_auth_plugin
    Preparing metadata (setup.py) … done
    Processing /var/www/onlyoffice/Tools/radicale/plugins/app_store_plugin
    Preparing metadata (setup.py) … done
    Processing /var/www/onlyoffice/Tools/radicale/plugins/app_rights_plugin
    Preparing metadata (setup.py) … done
    Collecting setuptools<82
    Using cached setuptools-81.0.0-py3-none-any.whl (1.1 MB)
    Collecting radicale==3.0.5
    Using cached Radicale-3.0.5-py3-none-any.whl (121 kB)
    Collecting defusedxml
    Using cached defusedxml-0.7.1-py2.py3-none-any.whl (25 kB)
    Collecting passlib
    Using cached passlib-1.7.4-py2.py3-none-any.whl (525 kB)
    Collecting vobject>=0.9.6
    Using cached vobject-0.9.9-py2.py3-none-any.whl (47 kB)
    Collecting python-dateutil>=2.7.3
    Using cached python_dateutil-2.9.0.post0-py2.py3-none-any.whl (229 kB)
    Collecting six>=1.5
    Using cached six-1.17.0-py2.py3-none-any.whl (11 kB)
    Collecting pytz
    Downloading pytz-2026.3.post1-py2.py3-none-any.whl (508 kB)
    ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━ 508.3/508.3 kB 71.3 kB/s eta 0:00:00
    Building wheels for collected packages: app_auth_plugin, app_store_plugin, app_rights_plugin
    Building wheel for app_auth_plugin (setup.py) … done
    Created wheel for app_auth_plugin: filename=app_auth_plugin-1.0.0-py3-none-any.whl size=2618 sha256=0b6abe6c4e2629a27b7e7814ce2ca68
    49340fab3dd76eabe078d94caed5afa69
    Stored in directory: /tmp/pip-ephem-wheel-cache-ssv63u9o/wheels/5a/54/73/e7744164c9a72590d99ef488280a1b50d46f07a9ac0ecbcb7a
    Building wheel for app_store_plugin (setup.py) … done
    Created wheel for app_store_plugin: filename=app_store_plugin-1.0.0-py3-none-any.whl size=15692 sha256=a688cee537d5289aec4bc4d0d761
    e0c2149a5d5fddac436b44420c398ee303da
    Stored in directory: /tmp/pip-ephem-wheel-cache-ssv63u9o/wheels/1a/93/7e/366b9464b3fac4592d182bab3341588f74a723bf1d4e003773
    Building wheel for app_rights_plugin (setup.py) … done
    Created wheel for app_rights_plugin: filename=app_rights_plugin-1.0.0-py3-none-any.whl size=2089 sha256=8b0a02ff42fd76ffd9802dfcae0
    37b5e05ab1875292f9e8ba65e780397708164
    Stored in directory: /tmp/pip-ephem-wheel-cache-ssv63u9o/wheels/b1/68/ce/aaa3f7cab40c3a5030b8fa29403f886efa5e83dfcba11f0d2a
    Successfully built app_auth_plugin app_store_plugin app_rights_plugin
    Installing collected packages: pytz, passlib, app_store_plugin, app_rights_plugin, app_auth_plugin, six, setuptools, defusedxml, pyth
    on-dateutil, vobject, radicale
    WARNING: The scripts change_tz and ics_diff are installed in ‘/usr/local/bin’ which is not on PATH.
    Consider adding this directory to PATH or, if you prefer to suppress this warning, use --no-warn-script-location.
    WARNING: The script radicale is installed in ‘/usr/local/bin’ which is not on PATH.
    Consider adding this directory to PATH or, if you prefer to suppress this warning, use --no-warn-script-location.
    Successfully installed app_auth_plugin-1.0.0 app_rights_plugin-1.0.0 app_store_plugin-1.0.0 defusedxml-0.7.1 passlib-1.7.4 python-dat
    eutil-2.9.0.post0 pytz-2026.2 radicale-3.0.5 setuptools-81.0.0 six-1.17.0 vobject-0.9.9
  • service elasticsearch stop
  • /usr/share/elasticsearch/bin/elasticsearch-plugin list
  • grep -q ingest-attachment
  • ‘[’ ‘!’ -d /var/www/onlyoffice/Data/Index/v7.16.3 ‘]’
  • ‘[’ -d /var/www/onlyoffice/Data/Index ‘]’
  • find /var/www/onlyoffice/Data/Index -maxdepth 1 ‘!’ -name v7.16.3 -type d -regex ‘./v[0-9]+.[0-9]+.[0-9]+.’ -exec rm -rf ‘{}’ ’
    ;’
  • mkdir -p /var/log/onlyoffice/Index
  • mkdir -p /var/www/onlyoffice/Data/Index/v7.16.3
  • chown -R elasticsearch:elasticsearch /var/www/onlyoffice/Data/Index/v7.16.3
  • chown -R elasticsearch:elasticsearch /var/log/onlyoffice/Index
  • sed ‘/path.data/s!path.data.*!path.data: /var/www/onlyoffice/Data/Index/v7.16.3!’ -i /etc/elasticsearch/elasticsearch.yml
  • sed ‘/path.logs/s!path.logs.*!path.logs: /var/log/onlyoffice/Index/!’ -i /etc/elasticsearch/elasticsearch.yml
  • grep -q indices.fielddata.cache.size /etc/elasticsearch/elasticsearch.yml
  • sed -i ‘s/indices.fielddata.cache.size.*/indices.fielddata.cache.size: 30%/’ /etc/elasticsearch/elasticsearch.yml
  • grep -q indices.memory.index_buffer_size /etc/elasticsearch/elasticsearch.yml
  • sed -i ‘s/indices.memory.index_buffer_size.*/indices.memory.index_buffer_size: 30%/’ /etc/elasticsearch/elasticsearch.yml
  • grep -q HeapDumpOnOutOfMemoryError /etc/elasticsearch/jvm.options
  • grep -q Dlog4j2.formatMsgNoLookups /etc/elasticsearch/jvm.options
  • sed -i ‘s/Dlog4j2.formatMsgNoLookups.*/Dlog4j2.formatMsgNoLookups=true/’ /etc/elasticsearch/jvm.options
  • grep -q ingest.geoip.downloader.enabled /etc/elasticsearch/elasticsearch.yml
  • sed -i ‘s/ingest.geoip.downloader.enabled.*/ingest.geoip.downloader.enabled: false/’ /etc/elasticsearch/elasticsearch.yml
    ++ free -m
    ++ grep -oP ‘\d+’
    ++ head -n 1
  • TOTAL_MEMORY=32096
  • MEMORY_REQUIREMENTS=12228
  • ‘[’ 32096 -gt 12228 ‘]’
  • ELASTICSEATCH_MEMORY=4g
  • grep -qE ‘[1]*-Xms[0-9]g’ /etc/elasticsearch/jvm.options
  • sed -i ‘s/-Xms[0-9]g/-Xms4g/’ /etc/elasticsearch/jvm.options
  • grep -qE ‘[2]*-Xmx[0-9]g’ /etc/elasticsearch/jvm.options
  • sed -i ‘s/-Xmx[0-9]g/-Xmx4g/’ /etc/elasticsearch/jvm.options
  • ‘[’ -d /etc/elasticsearch/ ‘]’
  • chmod g+ws /etc/elasticsearch/
  • service elasticsearch start
  • sed -i 1d /etc/logrotate.d/nginx
  • sed ‘1 i/var/log/nginx/.log /var/log/onlyoffice/nginx..log {’ -i /etc/logrotate.d/nginx
  • NGINX_ROOT_DIR=/etc/nginx
  • DOCUMENT_SERVER_PROTOCOL=http
  • DOCUMENT_SERVER_HOST=localhost:8083
  • DOCUMENT_SERVER_HOST_PROXY=‘localhost/ds-vpath’
  • DOCUMENT_SERVER_API_URL=‘/ds-vpath/’
  • DOCUMENT_SERVER_JWT_ENABLED=false
  • DOCUMENT_SERVER_JWT_SECRET=
  • DOCUMENT_SERVER_JWT_HEADER=
  • LICENSE_FILE_PATH=/var/www/onlyoffice/Data/license.lic
  • APP_ROOT_DIR=/var/www/onlyoffice/WebStudio
  • CONTROL_PANEL_PORT_80_TCP_ADDR=localhost:8082
  • SERVICE_SSO_AUTH_HOST_ADDR=localhost
  • SERVER_HOST=localhost
  • db_get onlyoffice-communityserver/ds-jwt-enabled
  • _db_cmd ‘GET onlyoffice-communityserver/ds-jwt-enabled’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/ds-jwt-enabled’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=true
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DOCUMENT_SERVER_JWT_ENABLED=true
  • db_get onlyoffice-communityserver/ds-jwt-secret
  • _db_cmd ‘GET onlyoffice-communityserver/ds-jwt-secret’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/ds-jwt-secret’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=LDtQfvRfpIAuYvY3cISL1iqWSqDXLJss
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DOCUMENT_SERVER_JWT_SECRET=LDtQfvRfpIAuYvY3cISL1iqWSqDXLJss
  • db_get onlyoffice-communityserver/ds-jwt-secret-header
  • _db_cmd ‘GET onlyoffice-communityserver/ds-jwt-secret-header’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/ds-jwt-secret-header’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=AuthorizationJwt
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DOCUMENT_SERVER_JWT_HEADER=AuthorizationJwt
  • grep -q onlyoffice-documentserver
  • dpkg -l
  • cp /etc/nginx/includes/onlyoffice-communityserver-proxy-to-documentserver.conf.template /etc/nginx/includes/onlyoffice-communityser
    ver-proxy-to-documentserver.conf
  • sed ‘s,{{DOCUMENT_SERVER_HOST_ADDR}},http://localhost:8083,’ -i /etc/nginx/includes/onlyoffice-communityserver-proxy-to-documents
    erver.conf
  • sed ‘/files.docservice.url.internal/s!(value\s*=\s*“)[^”]*“!\1http://localhost:8083”!’ -i /var/www/onlyoffice/WebStudio/
    web.appsettings.config
  • sed ‘/files.docservice.url.public/s!(value\s*=\s*“)[^”]*“!\1/ds-vpath/”!’ -i /var/www/onlyoffice/WebStudio/web.appsettin
    gs.config
  • sed ‘/files.docservice.url.portal/s!(value\s*=\s*“)[^”]*“!\1http://localhost”!’ -i /var/www/onlyoffice/WebStudio/web.app
    settings.config
  • sed ‘/files.docservice.url.internal/s!(value\s*=\s*“)[^”]*“!\1http://localhost:8083”!’ -i /var/www/onlyoffice/Services/T
    eamLabSvc/TeamLabSvc.exe.config
  • sed ‘/files.docservice.url.public/s!(value\s*=\s*“)[^”]*“!\1/ds-vpath/”!’ -i /var/www/onlyoffice/Services/TeamLabSvc/Tea
    mLabSvc.exe.config
  • sed ‘/files.docservice.url.portal/s!(value\s*=\s*“)[^”]*“!\1http://localhost”!’ -i /var/www/onlyoffice/Services/TeamLabS
    vc/TeamLabSvc.exe.config
  • dpkg -l onlyoffice-documentserver-ee
  • ‘[’ true = true ‘]’
  • sed ‘/files.docservice.secret/s!(value\s*=\s*“)[^”]*“!\1LDtQfvRfpIAuYvY3cISL1iqWSqDXLJss”!’ -i /var/www/onlyoffice/WebStudi
    o/web.appsettings.config
  • sed ‘/files.docservice.secret.header/s!(value\s*=\s*“)[^”]*“!\1AuthorizationJwt”!’ -i /var/www/onlyoffice/WebStudio/web.app
    settings.config
  • sed ‘/files.docservice.secret/s!(value\s*=\s*“)[^”]*“!\1LDtQfvRfpIAuYvY3cISL1iqWSqDXLJss”!’ -i /var/www/onlyoffice/Services
    /TeamLabSvc/TeamLabSvc.exe.config
  • sed ‘/files.docservice.secret.header/s!(value\s*=\s*“)[^”]*“!\1AuthorizationJwt”!’ -i /var/www/onlyoffice/Services/TeamLabS
    vc/TeamLabSvc.exe.config
  • dpkg -l
  • grep -q onlyoffice-controlpanel
  • cp /etc/nginx/includes/onlyoffice-communityserver-proxy-to-controlpanel.conf.template /etc/nginx/includes/onlyoffice-communityserve
    r-proxy-to-controlpanel.conf
  • sed ‘s,{{CONTROL_PANEL_HOST_ADDR}},localhost:8082,’ -i /etc/nginx/includes/onlyoffice-communityserver-proxy-to-controlpanel.conf
  • sed ‘s,{{SERVICE_SSO_AUTH_HOST_ADDR}},localhost,’ -i /etc/nginx/includes/onlyoffice-communityserver-proxy-to-controlpanel.conf
  • sed ‘/web.controlpanel.url/s/(value\s*=\s*“)[^”]*“/\1/controlpanel/”/’ -i /var/www/onlyoffice/WebStudio/web.appsettings.c
    onfig
  • sed ‘/web.controlpanel.url/s/(value\s*=\s*“)[^”]*“/\1/controlpanel/”/’ -i /var/www/onlyoffice/Services/TeamLabSvc/TeamLab
    Svc.exe.config
  • systemctl is-active onlyofficeControlPanel
  • service onlyofficeControlPanel restart
  • db_get onlyoffice-communityserver/imapsync-start-date
  • _db_cmd ‘GET onlyoffice-communityserver/imapsync-start-date’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/imapsync-start-date’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=2025-09-03T12:32:17
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • MAIL_IMAPSYNC_START_DATE=2025-09-03T12:32:17
  • ‘[’ -z 2025-09-03T12:32:17 ‘]’
  • true
  • sed ‘s_(“ImapSyncStartDate”:).*,\1 “2025-09-03T12:32:17”,’ -i /etc/onlyoffice/communityserver/mail.production.json
  • sed ‘/mail.imap-sync-start-date/s/value=“\S*”/value=“2025-09-03T12:32:17”/g’ -i /var/www/onlyoffice/WebStudio/web.appsettings.conf
    ig
  • sed ‘s!“value”:.*!“value”:\ “/var/www/onlyoffice/Data”!’ -i /etc/onlyoffice/communityserver/storage.production.json
  • sed ‘s!“folder”:.*,!“folder”:\ “/var/www/onlyoffice/Services”,!’ -i /etc/onlyoffice/communityserver/appsettings.production.json
  • OPENSSL_CONF=/etc/onlyoffice/communityserver/openssl.cnf
  • ‘[’ ‘!’ -f /etc/onlyoffice/communityserver/openssl.cnf ‘]’
  • dpkg -l
  • grep -q onlyoffice-xmppserver
  • sed ‘/web.talk/s/value=“\S*”/value=“true”/g’ -i /var/www/onlyoffice/WebStudio/web.appsettings.config
  • ‘[’ -f /etc/god/conf.d/onlyoffice.god ‘]’
  • db_stop
  • echo STOP
  • service nginx restart
    dpkg: erreur de traitement du paquet onlyoffice-communityserver (–configure) :
    le sous-processus paquet onlyoffice-communityserver script post-installation installé a renvoyé un état de sortie d’erreur 1
    Des erreurs ont été rencontrées pendant l’exécution :
    onlyoffice-communityserver
    E: Sub-process /usr/bin/dpkg returned an error code (1)
    root@workspace:/tmp#

  1. ^# ↩︎

  2. ^# ↩︎

Dear @sosfc
Thank you for the provided data! Please follow my steps:

sudo mv /etc/nginx/sites-available/onlyoffice /etc/nginx/sites-available/onlyoffice.bak
wget http://download.onlyoffice.com/repo/debian/pool/main/o/onlyoffice-communityserver/onlyoffice-communityserver_12.8.0.1971_all.deb -O /tmp/onlyoffice-communityserver.deb
sudo apt install /tmp/onlyoffice-communityserver.deb -o Dpkg::Options::="--force-confmiss"

If it doesn’t help, let’s check Nginx service and show us the output result of these commands:

sudo nginx -t
cat -n /etc/nginx/sites-available/onlyoffice
sudo service nginx restart; echo "exit code: $?"
systemctl status nginx.service
journalctl -xeu nginx.service --no-pager | tail -50
tail -50 /var/log/nginx/error.log
ls -la /etc/nginx/sites-enabled/ /etc/nginx/includes/

Hello Alexandre

There is the result (nok)

root@workspace:/home/sosfc# wget http://download.onlyoffice.com/repo/debian/pool/main/o/onlyoffice-communityserver/onlyoffice-communityserver_12.8.0.1971_all.deb -O /tmp/onlyoffice-communityserver.deb
–2026-08-13 08:40:16-- http://download.onlyoffice.com/repo/debian/pool/main/o/onlyoffice-communityserver/onlyoffice-communityserver_12.8.0.1971_all.deb
Résolution de download.onlyoffice.com (download.onlyoffice.com)… 109.61.86.70, 2a02:6ea0:f900::3
Connexion à download.onlyoffice.com (download.onlyoffice.com)|109.61.86.70|:80… connecté.
requête HTTP transmise, en attente de la réponse… 200 OK
Taille : 803067940 (766M) [binary/octet-stream]
Sauvegarde en : « /tmp/onlyoffice-communityserver.deb »

/tmp/onlyoffice-communityserver.deb 100%[=================================================================================================================>] 765,87M 1,92MB/s ds 7m 52s

2026-08-13 08:48:09 (1,62 MB/s) — « /tmp/onlyoffice-communityserver.deb » sauvegardé [803067940/803067940]

root@workspace:/home/sosfc# sudo apt install /tmp/onlyoffice-communityserver.deb -o Dpkg::Options::=“–force-confmiss”
Lecture des listes de paquets… Fait
Construction de l’arbre des dépendances… Fait
Lecture des informations d’état… Fait
Note : sélection de « onlyoffice-communityserver » au lieu de « /tmp/onlyoffice-communityserver.deb »
onlyoffice-communityserver est déjà la version la plus récente (12.8.0.1971).
0 mis à jour, 0 nouvellement installés, 0 à enlever et 137 non mis à jour.
1 partiellement installés ou enlevés.
Après cette opération, 0 o d’espace disque supplémentaires seront utilisés.
Souhaitez-vous continuer ? [O/n]
Paramétrage de onlyoffice-communityserver (12.8.0.1971) …

  • . /usr/share/debconf/confmodule
    ++ ‘[’ ‘!’ ‘’ ‘]’
    ++ PERL_DL_NONLAZY=1
    ++ export PERL_DL_NONLAZY
    ++ ‘[’ ‘’ ‘]’
    ++ exec /usr/share/debconf/frontend /var/lib/dpkg/info/onlyoffice-communityserver.postinst configure 12.7.1.1942
  • . /usr/share/debconf/confmodule
    ++ ‘[’ ‘!’ 1 ‘]’
    ++ ‘[’ -z ‘’ ‘]’
    ++ exec
    ++ ‘[’ ‘’ ‘]’
    ++ exec
    ++ DEBCONF_REDIR=1
    ++ export DEBCONF_REDIR
  • DIR=/var/www/onlyoffice
  • LOG_DIR=/var/log/onlyoffice
  • APP_DATA_DIR=/var/www/onlyoffice/Data
    ++ dpkg -l elasticsearch
    ++ tail -n1
    ++ awk ‘{print $3}’
  • ELASTIC_SEARCH_VERSION=7.16.3
  • APP_INDEX_DIR=/var/www/onlyoffice/Data/Index/v7.16.3
  • APP_SERVICES_DIR=/var/www/onlyoffice/Services
  • OLD_VERSION=12.7.1.1942
  • NGINX_ROOT_DIR=/etc/nginx
  • CONFIG_DIR=/etc/onlyoffice/communityserver
  • DB_HOST=
  • DB_USER=
  • DB_PWD=
  • DB_NAME=
  • case “$1” in
  • cat /etc/passwd
  • grep -q onlyoffice:
  • cat /etc/group
  • grep -q nginx:
  • grep -q nginx:
  • cat /etc/passwd
  • usermod -aG onlyoffice,nginx onlyoffice
  • ‘[’ ‘!’ -z 12.7.1.1942 ‘]’
    ++ awk -F. ‘{ printf(“%d%03d%03d%03d”, $1,$2,$3,$4); }’
  • OLDER_PACKAGE_VERSION=120070011942
  • install_db
  • db_get onlyoffice-communityserver/db-host
  • _db_cmd ‘GET onlyoffice-communityserver/db-host’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/db-host’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=127.0.0.1
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DB_HOST=127.0.0.1
  • db_get onlyoffice-communityserver/db-user
  • _db_cmd ‘GET onlyoffice-communityserver/db-user’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/db-user’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=root
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DB_USER=root
  • db_get onlyoffice-communityserver/db-pwd
  • _db_cmd ‘GET onlyoffice-communityserver/db-pwd’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/db-pwd’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=P8oxD5LqytmN
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DB_PWD=P8oxD5LqytmN
  • db_get onlyoffice-communityserver/db-name
  • _db_cmd ‘GET onlyoffice-communityserver/db-name’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/db-name’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=onlyoffice
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DB_NAME=onlyoffice
  • MYSQL=‘mysql -h127.0.0.1 -uroot’
  • ‘[’ -n P8oxD5LqytmN ‘]’
  • MYSQL=‘mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN’
  • sed ‘s/#max_connections.*/max_connections = 1000/’ -i /etc/mysql/my.cnf
  • CNF_PATH=/etc/mysql/mysql.conf.d/mysqld.cnf
  • CNF_SERVICE_PATH=/lib/systemd/system/mysql.service
  • mysql -V
  • grep -q MariaDB
  • ‘[’ -e /etc/mysql/mysql.conf.d/mysqld.cnf ‘]’
  • grep -q ‘^sql_mode’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/sql_mode.*/sql_mode = ‘‘‘NO_ENGINE_SUBSTITUTION’’’/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^max_connections’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/max_connections.*/max_connections = 1000/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^group_concat_max_len’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/group_concat_max_len.*/group_concat_max_len = 2048/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^max_allowed_packet’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/max_allowed_packet.*/max_allowed_packet = 1048576000/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^character_set_server’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/character_set_server.*/character_set_server = utf8/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^collation_server’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/collation_server.*/collation_server = utf8_general_ci/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^interactive_timeout’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/interactive_timeout.*/interactive_timeout = 900/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • grep -q ‘^wait_timeout’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘s/wait_timeout.*/wait_timeout = 900/’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • ‘[’ -e /lib/systemd/system/mysql.service ‘]’
  • grep -q ‘^LimitNOFILE’ /lib/systemd/system/mysql.service
  • sed ‘s/LimitNOFILE.*/LimitNOFILE = infinity/’ -i /lib/systemd/system/mysql.service
  • grep -q ‘^LimitMEMLOCK’ /lib/systemd/system/mysql.service
  • sed ‘s/LimitMEMLOCK.*/LimitMEMLOCK = infinity/’ -i /lib/systemd/system/mysql.service
  • systemctl daemon-reload
  • sed -i ‘/^default-authentication-plugin/d’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN -e ‘;’
    ++ mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN -e ‘SHOW VARIABLES LIKE ‘‘‘default_authentication_plugin’’’;’ -s
    ++ awk ‘{print $2}’
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • MYSQL_AUTHENTICATION_PLUGIN=caching_sha2_password
  • ‘[’ -n caching_sha2_password ‘]’
  • grep -q ‘^default-authentication-plugin’ /etc/mysql/mysql.conf.d/mysqld.cnf
  • sed ‘/[mysqld]/a default-authentication-plugin = caching_sha2_password’ -i /etc/mysql/mysql.conf.d/mysqld.cnf
  • ‘[’ root = root ‘]’
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN -D mysql -e ‘ALTER USER ‘‘‘root’’’@’‘‘localhost’’’ IDENTIFIED WITH caching_sha2_password BY ‘‘‘P8oxD5LqytmN’’’’
  • service mysql restart
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN -e ‘CREATE DATABASE IF NOT EXISTS onlyoffice CHARACTER SET utf8 COLLATE utf8_general_ci;’
    mysql: [Warning] Using a password on the command line interface can be insecure.
    ++ mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN --silent --skip-column-names -e ‘SELECT COUNT(*) FROM information_schema.tables WHERE table_schema=’‘‘onlyoffice’’‘’
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • DB_TABLES_COUNT=208
  • ‘[’ 208 -eq 0 ‘]’
    ++ ls /var/www/onlyoffice/Sql/onlyoffice.upgrade80.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade81.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade85.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade86.sql /var
    /www/onlyoffice/Sql/onlyoffice.upgrade87.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade88.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade890.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade892.sql /var/www/onl
    yoffice/Sql/onlyoffice.upgrade90.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade91.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade950.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade952.sql /var/www/onlyoffice/
    Sql/onlyoffice.upgrade960.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade962.sql /var/www/onlyoffice/Sql/onlyoffice.upgrade963.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev100.sql /var/www/onlyoffice/Sql/o
    nlyoffice.upgradev105.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev110.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev111.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev115.sql /var/www/onlyoffice/Sql/onl
    yoffice.upgradev116.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev120.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev121.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev125.sql /var/www/onlyoffice/Sql/onlyo
    ffice.upgradev126.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev127.sql /var/www/onlyoffice/Sql/onlyoffice.upgradev128.sql
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • for i in $(ls $DIR/Sql/onlyoffice.upgrade*)
  • mysql -h127.0.0.1 -uroot -pP8oxD5LqytmN onlyoffice
    mysql: [Warning] Using a password on the command line interface can be insecure.
  • grep -q client_max_body_size /etc/nginx/nginx.conf
  • sed -i ‘s/(client_max_body_size).*?;/\1 100m;/’ /etc/nginx/nginx.conf
  • ‘[’ ‘!’ -f /proc/net/if_inet6 ‘]’
  • apply_connection_string
  • binDirs=(“WebStudio” “ApiSystem” “Services/TeamLabSvc”)
  • ‘[’ 127.0.0.1 ‘!=’ localhost ‘]’
  • ‘[’ -d /var/www/onlyoffice/ ‘]’
  • for i in “${!binDirs[@]}”
  • find /var/www/onlyoffice/WebStudio -type f -name ‘.[cC]onfig’ -exec sed -i 's/connectionString=./connectionString=“Server=127.0.0.1;Database=onlyoffice;User ID=root;Password=P8oxD5LqytmN;Pooling=true;Ch
    aracter Set=utf8;AutoEnlist=false;SSL Mode=none;AllowPublicKeyRetrieval=true;Connection Timeout=30;Maximum Pool Size=300;” providerName=“MySql.Data.MySqlClient”/>/’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • find /var/www/onlyoffice/ApiSystem -type f -name ‘.[cC]onfig’ -exec sed -i 's/connectionString=./connectionString=“Server=127.0.0.1;Database=onlyoffice;User ID=root;Password=P8oxD5LqytmN;Pooling=true;Ch
    aracter Set=utf8;AutoEnlist=false;SSL Mode=none;AllowPublicKeyRetrieval=true;Connection Timeout=30;Maximum Pool Size=300;” providerName=“MySql.Data.MySqlClient”/>/’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • find /var/www/onlyoffice/Services/TeamLabSvc -type f -name ‘.[cC]onfig’ -exec sed -i 's/connectionString=./connectionString=“Server=127.0.0.1;Database=onlyoffice;User ID=root;Password=P8oxD5LqytmN;Pooli
    ng=true;Character Set=utf8;AutoEnlist=false;SSL Mode=none;AllowPublicKeyRetrieval=true;Connection Timeout=30;Maximum Pool Size=300;” providerName=“MySql.Data.MySqlClient”/>/’ ‘{}’ ‘;’
  • find /var/www/onlyoffice/Services/ASC.UrlShortener/config -type f -name ‘.json’ -exec sed -i -e 's!(“host”:).,!\1 “127.0.0.1”,!’ -e ‘s!(“user”:).,!\1 “root”,!’ -e 's!(“password”:).,!\1 “P8oxD5Lq
    ytmN”,!’ -e ‘s!(“database”:).*!\1 “onlyoffice”!’ ‘{}’ ‘;’
  • sed -i ‘s/Server=.*/Server=127.0.0.1;Port=3306;Database=onlyoffice;User ID=root;Password=P8oxD5LqytmN;Pooling=true;Character Set=utf8;AutoEnlist=false;SSL Mode=none;AllowPublicKeyRetrieval=True;Connection
    Reset=false",/g’ /etc/onlyoffice/communityserver/appsettings.production.json
  • apply_core_machinekey
  • db_get onlyoffice-communityserver/machinekey
  • _db_cmd ‘GET onlyoffice-communityserver/machinekey’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/machinekey’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=kAH2nodUYizf
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • ‘[’ ‘!’ -z 120070011942 ‘]’
  • CORE_MACHINEKEY=kAH2nodUYizf
  • ‘[’ -z kAH2nodUYizf ‘]’
  • true
  • sed ‘s^(machine_key)\s*=.*^\1 = kAH2nodUYizf^g’ -i /var/www/onlyoffice/Services/TeamLabSvc/radicale.config
  • binDirs=(“$DIR/ApiSystem/” “$DIR/WebStudio” “$DIR/controlpanel/www/config” “$APP_SERVICES_DIR” “$CONFIG_DIR”)
  • for i in “${!binDirs[@]}”
  • ‘[’ -d /var/www/onlyoffice/ApiSystem/ ‘]’
  • find /var/www/onlyoffice/ApiSystem/ -type f -name ‘.[cC]onfig’ -exec sed -i '/core.\machinekey/s_(value\s=\s*“)[^”]*"\1kAH2nodUYizf"’ ‘{}’ ‘;’
  • find /var/www/onlyoffice/ApiSystem/ -type f -name ‘.json’ -exec sed -i 's_(“core.machinekey”:|“machinekey”:).,\1 “kAH2nodUYizf”,’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • ‘[’ -d /var/www/onlyoffice/WebStudio ‘]’
  • find /var/www/onlyoffice/WebStudio -type f -name ‘.[cC]onfig’ -exec sed -i '/core.\machinekey/s_(value\s=\s*“)[^”]*"\1kAH2nodUYizf"’ ‘{}’ ‘;’
  • find /var/www/onlyoffice/WebStudio -type f -name ‘.json’ -exec sed -i 's_(“core.machinekey”:|“machinekey”:).,\1 “kAH2nodUYizf”,’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • ‘[’ -d /var/www/onlyoffice/controlpanel/www/config ‘]’
  • find /var/www/onlyoffice/controlpanel/www/config -type f -name ‘.[cC]onfig’ -exec sed -i '/core.\machinekey/s_(value\s=\s*“)[^”]*"\1kAH2nodUYizf"’ ‘{}’ ‘;’
  • find /var/www/onlyoffice/controlpanel/www/config -type f -name ‘.json’ -exec sed -i 's_(“core.machinekey”:|“machinekey”:).,\1 “kAH2nodUYizf”,’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • ‘[’ -d /var/www/onlyoffice/Services ‘]’
  • find /var/www/onlyoffice/Services -type f -name ‘.[cC]onfig’ -exec sed -i '/core.\machinekey/s_(value\s=\s*“)[^”]*"\1kAH2nodUYizf"’ ‘{}’ ‘;’
  • find /var/www/onlyoffice/Services -type f -name ‘.json’ -exec sed -i 's_(“core.machinekey”:|“machinekey”:).,\1 “kAH2nodUYizf”,’ ‘{}’ ‘;’
  • for i in “${!binDirs[@]}”
  • ‘[’ -d /etc/onlyoffice/communityserver ‘]’
  • find /etc/onlyoffice/communityserver -type f -name ‘.[cC]onfig’ -exec sed -i '/core.\machinekey/s_(value\s=\s*“)[^”]*"\1kAH2nodUYizf"’ ‘{}’ ‘;’
  • find /etc/onlyoffice/communityserver -type f -name ‘.json’ -exec sed -i 's_(“core.machinekey”:|“machinekey”:).,\1 “kAH2nodUYizf”,’ ‘{}’ ‘;’
  • mkdir -p /etc/mono/registry/LocalMachine
  • mkdir -p /usr/share/.mono/keypairs
  • mkdir -p /var/log/onlyoffice
  • mkdir -p /var/www/onlyoffice/Data
  • mkdir -p /var/www/onlyoffice/DocumentServerData
  • mkdir -p /var/cache/nginx/onlyoffice
  • mkdir -p /var/run/onlyoffice
  • rm -dfr /tmp/onlyoffice-communityserver.deb /tmp/onlyoffice-temp-aspnet-0
  • rm -dfr /var/run/onlyoffice/onlyofficeApiSystem.socket /var/run/onlyoffice/onlyoffice.socket
  • rm -dfr ‘/var/cache/nginx/onlyoffice/*’
  • mkdir -p -m 700 /var/www/onlyoffice/.config/.mono/keypairs
  • chown nginx:nginx -R /var/cache/nginx/onlyoffice
  • chown onlyoffice:nginx -R /var/run/onlyoffice
  • chmod g+s+w /var/run/onlyoffice
  • rm -f /etc/nginx/sites-enabled/default
  • rm -f /etc/nginx/sites-enabled/onlyoffice-apisystem
  • which apparmor_parser
    /usr/sbin/apparmor_parser
  • ‘[’ ‘!’ -f /etc/apparmor.d/disable/usr.sbin.mysqld ‘]’
  • ‘[’ -f /etc/apparmor.d/disable/ ‘]’
  • ‘[’ -d /etc/apport/blacklist.d ‘]’
    ++ python3 -c ‘import sys; print(sys.version_info.minor)’
  • ‘[’ -f /usr/lib/python3.11/EXTERNALLY-MANAGED ‘]’
  • pip_packages+=(“setuptools<82” “radicale==3.0.5”)
  • for pkg in requests importlib-metadata
  • dpkg -l python3-requests
  • for pkg in requests importlib-metadata
  • dpkg -l python3-importlib-metadata
  • export PIP_ROOT_USER_ACTION=ignore
  • PIP_ROOT_USER_ACTION=ignore
  • python3 -m pip install --upgrade --ignore-installed ‘setuptools<82’ radicale==3.0.5 /var/www/onlyoffice/Tools/radicale/plugins/app_auth_plugin/. /var/www/onlyoffice/Tools/radicale/plugins/app_store_plugin
    /. /var/www/onlyoffice/Tools/radicale/plugins/app_rights_plugin/.
    Processing /var/www/onlyoffice/Tools/radicale/plugins/app_auth_plugin
    Preparing metadata (setup.py) … done
    Processing /var/www/onlyoffice/Tools/radicale/plugins/app_store_plugin
    Preparing metadata (setup.py) … done
    Processing /var/www/onlyoffice/Tools/radicale/plugins/app_rights_plugin
    Preparing metadata (setup.py) … done
    Collecting setuptools<82
    Using cached setuptools-81.0.0-py3-none-any.whl (1.1 MB)
    Collecting radicale==3.0.5
    Using cached Radicale-3.0.5-py3-none-any.whl (121 kB)
    Collecting defusedxml
    Using cached defusedxml-0.7.1-py2.py3-none-any.whl (25 kB)
    Collecting passlib
    Using cached passlib-1.7.4-py2.py3-none-any.whl (525 kB)
    Collecting vobject>=0.9.6
    Using cached vobject-0.9.9-py2.py3-none-any.whl (47 kB)
    Collecting python-dateutil>=2.7.3
    Using cached python_dateutil-2.9.0.post0-py2.py3-none-any.whl (229 kB)
    Collecting six>=1.5
    Using cached six-1.17.0-py2.py3-none-any.whl (11 kB)
    Collecting pytz
    Using cached pytz-2026.3.post1-py2.py3-none-any.whl (508 kB)
    Building wheels for collected packages: app_auth_plugin, app_store_plugin, app_rights_plugin
    Building wheel for app_auth_plugin (setup.py) … done
    Created wheel for app_auth_plugin: filename=app_auth_plugin-1.0.0-py3-none-any.whl size=2618 sha256=ad1b672cace11944a50c991701c015a081970e423e1643e0cb449765eb7d3ec3
    Stored in directory: /tmp/pip-ephem-wheel-cache-_hyi3cn6/wheels/5a/54/73/e7744164c9a72590d99ef488280a1b50d46f07a9ac0ecbcb7a
    Building wheel for app_store_plugin (setup.py) … done
    Created wheel for app_store_plugin: filename=app_store_plugin-1.0.0-py3-none-any.whl size=15692 sha256=3be89301dbaaa5499bfcd3967423bbf96b9cc98e88bdb9f40015bfb9b9aacde6
    Stored in directory: /tmp/pip-ephem-wheel-cache-_hyi3cn6/wheels/1a/93/7e/366b9464b3fac4592d182bab3341588f74a723bf1d4e003773
    Building wheel for app_rights_plugin (setup.py) … done
    Created wheel for app_rights_plugin: filename=app_rights_plugin-1.0.0-py3-none-any.whl size=2089 sha256=bf7eb877ff83535bc958014ca2afd61cfc5c2197857c43e5f9cb553896c6cd6b
    Stored in directory: /tmp/pip-ephem-wheel-cache-_hyi3cn6/wheels/b1/68/ce/aaa3f7cab40c3a5030b8fa29403f886efa5e83dfcba11f0d2a
    Successfully built app_auth_plugin app_store_plugin app_rights_plugin
    Installing collected packages: pytz, passlib, app_store_plugin, app_rights_plugin, app_auth_plugin, six, setuptools, defusedxml, python-dateutil, vobject, radicale
    WARNING: The scripts change_tz and ics_diff are installed in ‘/usr/local/bin’ which is not on PATH.
    Consider adding this directory to PATH or, if you prefer to suppress this warning, use --no-warn-script-location.
    WARNING: The script radicale is installed in ‘/usr/local/bin’ which is not on PATH.
    Consider adding this directory to PATH or, if you prefer to suppress this warning, use --no-warn-script-location.
    Successfully installed app_auth_plugin-1.0.0 app_rights_plugin-1.0.0 app_store_plugin-1.0.0 defusedxml-0.7.1 passlib-1.7.4 python-dateutil-2.9.0.post0 pytz-2026.2 radicale-3.0.5 setuptools-81.0.0 six-1.17.0
    vobject-0.9.9
  • service elasticsearch stop
  • /usr/share/elasticsearch/bin/elasticsearch-plugin list
  • grep -q ingest-attachment
  • ‘[’ ‘!’ -d /var/www/onlyoffice/Data/Index/v7.16.3 ‘]’
  • ‘[’ -d /var/www/onlyoffice/Data/Index ‘]’
  • find /var/www/onlyoffice/Data/Index -maxdepth 1 ‘!’ -name v7.16.3 -type d -regex ‘./v[0-9]+.[0-9]+.[0-9]+.’ -exec rm -rf ‘{}’ ‘;’
  • mkdir -p /var/log/onlyoffice/Index
  • mkdir -p /var/www/onlyoffice/Data/Index/v7.16.3
  • chown -R elasticsearch:elasticsearch /var/www/onlyoffice/Data/Index/v7.16.3
  • chown -R elasticsearch:elasticsearch /var/log/onlyoffice/Index
  • sed ‘/path.data/s!path.data.*!path.data: /var/www/onlyoffice/Data/Index/v7.16.3!’ -i /etc/elasticsearch/elasticsearch.yml
  • sed ‘/path.logs/s!path.logs.*!path.logs: /var/log/onlyoffice/Index/!’ -i /etc/elasticsearch/elasticsearch.yml
  • grep -q indices.fielddata.cache.size /etc/elasticsearch/elasticsearch.yml
  • sed -i ‘s/indices.fielddata.cache.size.*/indices.fielddata.cache.size: 30%/’ /etc/elasticsearch/elasticsearch.yml
  • grep -q indices.memory.index_buffer_size /etc/elasticsearch/elasticsearch.yml
  • sed -i ‘s/indices.memory.index_buffer_size.*/indices.memory.index_buffer_size: 30%/’ /etc/elasticsearch/elasticsearch.yml
  • grep -q HeapDumpOnOutOfMemoryError /etc/elasticsearch/jvm.options
  • grep -q Dlog4j2.formatMsgNoLookups /etc/elasticsearch/jvm.options
  • sed -i ‘s/Dlog4j2.formatMsgNoLookups.*/Dlog4j2.formatMsgNoLookups=true/’ /etc/elasticsearch/jvm.options
  • grep -q ingest.geoip.downloader.enabled /etc/elasticsearch/elasticsearch.yml
  • sed -i ‘s/ingest.geoip.downloader.enabled.*/ingest.geoip.downloader.enabled: false/’ /etc/elasticsearch/elasticsearch.yml
    ++ free -m
    ++ head -n 1
    ++ grep -oP ‘\d+’
  • TOTAL_MEMORY=32096
  • MEMORY_REQUIREMENTS=12228
  • ‘[’ 32096 -gt 12228 ‘]’
  • ELASTICSEATCH_MEMORY=4g
  • grep -qE ‘[1]*-Xms[0-9]g’ /etc/elasticsearch/jvm.options
  • sed -i ‘s/-Xms[0-9]g/-Xms4g/’ /etc/elasticsearch/jvm.options
  • grep -qE ‘[2]*-Xmx[0-9]g’ /etc/elasticsearch/jvm.options
  • sed -i ‘s/-Xmx[0-9]g/-Xmx4g/’ /etc/elasticsearch/jvm.options
  • ‘[’ -d /etc/elasticsearch/ ‘]’
  • chmod g+ws /etc/elasticsearch/
  • service elasticsearch start
  • sed -i 1d /etc/logrotate.d/nginx
  • sed ‘1 i/var/log/nginx/.log /var/log/onlyoffice/nginx..log {’ -i /etc/logrotate.d/nginx
  • NGINX_ROOT_DIR=/etc/nginx
  • DOCUMENT_SERVER_PROTOCOL=http
  • DOCUMENT_SERVER_HOST=localhost:8083
  • DOCUMENT_SERVER_HOST_PROXY=‘localhost/ds-vpath’
  • DOCUMENT_SERVER_API_URL=‘/ds-vpath/’
  • DOCUMENT_SERVER_JWT_ENABLED=false
  • DOCUMENT_SERVER_JWT_SECRET=
  • DOCUMENT_SERVER_JWT_HEADER=
  • LICENSE_FILE_PATH=/var/www/onlyoffice/Data/license.lic
  • APP_ROOT_DIR=/var/www/onlyoffice/WebStudio
  • CONTROL_PANEL_PORT_80_TCP_ADDR=localhost:8082
  • SERVICE_SSO_AUTH_HOST_ADDR=localhost
  • SERVER_HOST=localhost
  • db_get onlyoffice-communityserver/ds-jwt-enabled
  • _db_cmd ‘GET onlyoffice-communityserver/ds-jwt-enabled’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/ds-jwt-enabled’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=true
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DOCUMENT_SERVER_JWT_ENABLED=true
  • db_get onlyoffice-communityserver/ds-jwt-secret
  • _db_cmd ‘GET onlyoffice-communityserver/ds-jwt-secret’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/ds-jwt-secret’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=LDtQfvRfpIAuYvY3cISL1iqWSqDXLJss
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DOCUMENT_SERVER_JWT_SECRET=LDtQfvRfpIAuYvY3cISL1iqWSqDXLJss
  • db_get onlyoffice-communityserver/ds-jwt-secret-header
  • _db_cmd ‘GET onlyoffice-communityserver/ds-jwt-secret-header’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/ds-jwt-secret-header’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=AuthorizationJwt
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • DOCUMENT_SERVER_JWT_HEADER=AuthorizationJwt
  • dpkg -l
  • grep -q onlyoffice-documentserver
  • cp /etc/nginx/includes/onlyoffice-communityserver-proxy-to-documentserver.conf.template /etc/nginx/includes/onlyoffice-communityserver-proxy-to-documentserver.conf
  • sed ‘s,{{DOCUMENT_SERVER_HOST_ADDR}},http://localhost:8083,’ -i /etc/nginx/includes/onlyoffice-communityserver-proxy-to-documentserver.conf
  • sed ‘/files.docservice.url.internal/s!(value\s*=\s*“)[^”]*“!\1http://localhost:8083”!’ -i /var/www/onlyoffice/WebStudio/web.appsettings.config
  • sed ‘/files.docservice.url.public/s!(value\s*=\s*“)[^”]*“!\1/ds-vpath/”!’ -i /var/www/onlyoffice/WebStudio/web.appsettings.config
  • sed ‘/files.docservice.url.portal/s!(value\s*=\s*“)[^”]*“!\1http://localhost”!’ -i /var/www/onlyoffice/WebStudio/web.appsettings.config
  • sed ‘/files.docservice.url.internal/s!(value\s*=\s*“)[^”]*“!\1http://localhost:8083”!’ -i /var/www/onlyoffice/Services/TeamLabSvc/TeamLabSvc.exe.config
  • sed ‘/files.docservice.url.public/s!(value\s*=\s*“)[^”]*“!\1/ds-vpath/”!’ -i /var/www/onlyoffice/Services/TeamLabSvc/TeamLabSvc.exe.config
  • sed ‘/files.docservice.url.portal/s!(value\s*=\s*“)[^”]*“!\1http://localhost”!’ -i /var/www/onlyoffice/Services/TeamLabSvc/TeamLabSvc.exe.config
  • dpkg -l onlyoffice-documentserver-ee
  • ‘[’ true = true ‘]’
  • sed ‘/files.docservice.secret/s!(value\s*=\s*“)[^”]*“!\1LDtQfvRfpIAuYvY3cISL1iqWSqDXLJss”!’ -i /var/www/onlyoffice/WebStudio/web.appsettings.config
  • sed ‘/files.docservice.secret.header/s!(value\s*=\s*“)[^”]*“!\1AuthorizationJwt”!’ -i /var/www/onlyoffice/WebStudio/web.appsettings.config
  • sed ‘/files.docservice.secret/s!(value\s*=\s*“)[^”]*“!\1LDtQfvRfpIAuYvY3cISL1iqWSqDXLJss”!’ -i /var/www/onlyoffice/Services/TeamLabSvc/TeamLabSvc.exe.config
  • sed ‘/files.docservice.secret.header/s!(value\s*=\s*“)[^”]*“!\1AuthorizationJwt”!’ -i /var/www/onlyoffice/Services/TeamLabSvc/TeamLabSvc.exe.config
  • dpkg -l
  • grep -q onlyoffice-controlpanel
  • cp /etc/nginx/includes/onlyoffice-communityserver-proxy-to-controlpanel.conf.template /etc/nginx/includes/onlyoffice-communityserver-proxy-to-controlpanel.conf
  • sed ‘s,{{CONTROL_PANEL_HOST_ADDR}},localhost:8082,’ -i /etc/nginx/includes/onlyoffice-communityserver-proxy-to-controlpanel.conf
  • sed ‘s,{{SERVICE_SSO_AUTH_HOST_ADDR}},localhost,’ -i /etc/nginx/includes/onlyoffice-communityserver-proxy-to-controlpanel.conf
  • sed ‘/web.controlpanel.url/s/(value\s*=\s*“)[^”]*“/\1/controlpanel/”/’ -i /var/www/onlyoffice/WebStudio/web.appsettings.config
  • sed ‘/web.controlpanel.url/s/(value\s*=\s*“)[^”]*“/\1/controlpanel/”/’ -i /var/www/onlyoffice/Services/TeamLabSvc/TeamLabSvc.exe.config
  • systemctl is-active onlyofficeControlPanel
  • service onlyofficeControlPanel restart
  • db_get onlyoffice-communityserver/imapsync-start-date
  • _db_cmd ‘GET onlyoffice-communityserver/imapsync-start-date’
  • _db_internal_IFS=’
  • IFS=’ ’
  • printf ‘%s\n’ ‘GET onlyoffice-communityserver/imapsync-start-date’
  • IFS=’
  • read -r _db_internal_line
  • IFS=’
  • RET=2025-09-03T12:32:17
  • case ${_db_internal_line%%[ ]*} in
  • return 0
  • MAIL_IMAPSYNC_START_DATE=2025-09-03T12:32:17
  • ‘[’ -z 2025-09-03T12:32:17 ‘]’
  • true
  • sed ‘s_(“ImapSyncStartDate”:).*,\1 “2025-09-03T12:32:17”,’ -i /etc/onlyoffice/communityserver/mail.production.json
  • sed ‘/mail.imap-sync-start-date/s/value=“\S*”/value=“2025-09-03T12:32:17”/g’ -i /var/www/onlyoffice/WebStudio/web.appsettings.config
  • sed ‘s!“value”:.*!“value”:\ “/var/www/onlyoffice/Data”!’ -i /etc/onlyoffice/communityserver/storage.production.json
  • sed ‘s!“folder”:.*,!“folder”:\ “/var/www/onlyoffice/Services”,!’ -i /etc/onlyoffice/communityserver/appsettings.production.json
  • OPENSSL_CONF=/etc/onlyoffice/communityserver/openssl.cnf
  • ‘[’ ‘!’ -f /etc/onlyoffice/communityserver/openssl.cnf ‘]’
  • dpkg -l
  • grep -q onlyoffice-xmppserver
  • sed ‘/web.talk/s/value=“\S*”/value=“true”/g’ -i /var/www/onlyoffice/WebStudio/web.appsettings.config
  • ‘[’ -f /etc/god/conf.d/onlyoffice.god ‘]’
  • db_stop
  • echo STOP
  • service nginx restart
    dpkg: erreur de traitement du paquet onlyoffice-communityserver (–configure) :
    le sous-processus paquet onlyoffice-communityserver script post-installation installé a renvoyé un état de sortie d’erreur 1
    Des erreurs ont été rencontrées pendant l’exécution :
    onlyoffice-communityserver
    E: Sub-process /usr/bin/dpkg returned an error code (1)
    root@workspace:/home/sosfc#

root@workspace:/home/sosfc# sudo nginx -t
2026/08/13 08:51:24 [emerg] 2305828#2305828: unexpected “{” in /etc/nginx/sites-enabled/onlyoffice:19
nginx: configuration file /etc/nginx/nginx.conf test failed
root@workspace:/home/sosfc# cat -n /etc/nginx/sites-available/onlyoffice
cat: /etc/nginx/sites-available/onlyoffice: Aucun fichier ou dossier de ce type
root@workspace:/home/sosfc# sudo service nginx restart; echo “exit code: $?”
Job for nginx.service failed because the control process exited with error code.
See “systemctl status nginx.service” and “journalctl -xeu nginx.service” for details.
exit code: 1
root@workspace:/home/sosfc# tail -50 /var/log/nginx/error.log
root@workspace:/home/sosfc# ls -la /etc/nginx/sites-enabled/ /etc/nginx/includes/
/etc/nginx/includes/:
total 80
drwxr-xr-x 2 root root 4096 13 août 08:50 .
drwxr-xr-x 9 root root 4096 13 août 08:49 ..
-rw-r–r-- 1 root root 51 13 juil. 17:41 ds-cache.conf
lrwxrwxrwx 1 root root 61 28 avril 2015 ds-common.conf → ../../onlyoffice/documentserver/nginx/includes/ds-common.conf
lrwxrwxrwx 1 root root 65 28 avril 2015 ds-docservice.conf → ../../onlyoffice/documentserver/nginx/includes/ds-docservice.conf
lrwxrwxrwx 1 root root 70 28 avril 2015 ds-example.conf → ../../onlyoffice/documentserver-example/nginx/includes/ds-example.conf
lrwxrwxrwx 1 root root 66 28 avril 2015 ds-letsencrypt.conf → ../../onlyoffice/documentserver/nginx/includes/ds-letsencrypt.conf
lrwxrwxrwx 1 root root 65 28 avril 2015 ds-mime.types.conf → ../../onlyoffice/documentserver/nginx/includes/ds-mime.types.conf
lrwxrwxrwx 1 root root 63 28 avril 2015 http-common.conf → ../../onlyoffice/documentserver/nginx/includes/http-common.conf
-rw-r–r-- 1 root root 3706 17 avril 2015 onlyoffice-communityserver-common.conf
-rw-r–r-- 1 root root 1551 17 avril 2015 onlyoffice-communityserver-common.conf.template
-rw-r–r-- 1 root root 1154 17 avril 2015 onlyoffice-communityserver-common-init.conf.template
-rw-r–r-- 1 root root 3572 17 avril 2015 onlyoffice-communityserver-common-ssl.conf.template
-rw-r–r-- 1 root root 82 17 avril 2015 onlyoffice-communityserver-letsencrypt.conf
-rw-r–r-- 1 root root 685 17 avril 2015 onlyoffice-communityserver-nginx.conf.template
-rw-r–r-- 1 root root 642 13 août 08:50 onlyoffice-communityserver-proxy-to-controlpanel.conf
-rw-r–r-- 1 root root 655 17 avril 2015 onlyoffice-communityserver-proxy-to-controlpanel.conf.template
-rw-r–r-- 1 root root 685 13 août 08:50 onlyoffice-communityserver-proxy-to-documentserver.conf
-rw-r–r-- 1 root root 693 17 avril 2015 onlyoffice-communityserver-proxy-to-documentserver.conf.template
-rw-r–r-- 1 root root 2746 17 avril 2015 onlyoffice-communityserver-services.conf

/etc/nginx/sites-enabled/:
total 12
drwxr-xr-x 2 root root 4096 13 août 08:39 .
drwxr-xr-x 9 root root 4096 13 août 08:49 ..
-rw-r–r-- 1 root root 3614 30 oct. 2025 onlyoffice
root@workspace:/home/sosfc# journalctl -xeu nginx.service --no-pager | tail -50
août 13 08:52:21 workspace nginx[2305920]: 2026/08/13 08:52:21 [emerg] 2305920#2305920: unexpected “{” in /etc/nginx/sites-enabled/onlyoffice:19
août 13 08:52:21 workspace nginx[2305920]: nginx: configuration file /etc/nginx/nginx.conf test failed
août 13 08:52:21 workspace systemd[1]: nginx.service: Control process exited, code=exited, status=1/FAILURE
░░ Subject: Unit process exited
░░ Defined-By: systemd
░░ Support: Debian -- User Support
░░
░░ An ExecStartPre= process belonging to unit nginx.service has exited.
░░
░░ The process’ exit code is ‘exited’ and its exit status is 1.
août 13 08:52:21 workspace systemd[1]: nginx.service: Failed with result ‘exit-code’.
░░ Subject: Unit failed
░░ Defined-By: systemd
░░ Support: Debian -- User Support
░░
░░ The unit nginx.service has entered the ‘failed’ state with result ‘exit-code’.
août 13 08:52:21 workspace systemd[1]: Failed to start nginx.service - A high performance web server and a reverse proxy server.
░░ Subject: L’unité (unit) nginx.service a échoué
░░ Defined-By: systemd
░░ Support: Debian -- User Support
░░
░░ L’unité (unit) nginx.service a échoué, avec le résultat failed.
août 13 08:52:56 workspace systemd[1]: Starting nginx.service - A high performance web server and a reverse proxy server…
░░ Subject: L’unité (unit) nginx.service a commencé à démarrer
░░ Defined-By: systemd
░░ Support: Debian -- User Support
░░
░░ L’unité (unit) nginx.service a commencé à démarrer.
août 13 08:52:56 workspace nginx[2305995]: 2026/08/13 08:52:56 [emerg] 2305995#2305995: unexpected “{” in /etc/nginx/sites-enabled/onlyoffice:19
août 13 08:52:56 workspace nginx[2305995]: nginx: configuration file /etc/nginx/nginx.conf test failed
août 13 08:52:56 workspace systemd[1]: nginx.service: Control process exited, code=exited, status=1/FAILURE
░░ Subject: Unit process exited
░░ Defined-By: systemd
░░ Support: Debian -- User Support
░░
░░ An ExecStartPre= process belonging to unit nginx.service has exited.
░░
░░ The process’ exit code is ‘exited’ and its exit status is 1.
août 13 08:52:56 workspace systemd[1]: nginx.service: Failed with result ‘exit-code’.
░░ Subject: Unit failed
░░ Defined-By: systemd
░░ Support: Debian -- User Support
░░
░░ The unit nginx.service has entered the ‘failed’ state with result ‘exit-code’.
août 13 08:52:56 workspace systemd[1]: Failed to start nginx.service - A high performance web server and a reverse proxy server.
░░ Subject: L’unité (unit) nginx.service a échoué
░░ Defined-By: systemd
░░ Support: Debian -- User Support
░░
░░ L’unité (unit) nginx.service a échoué, avec le résultat failed.
root@workspace:/home/sosfc#

The line 19 of my file is

{{DOCKER_APP_SUBNET}} 0;

But I don’t have docker installed on this server (packages version)


  1. ^# ↩︎

  2. ^# ↩︎

Please move the config from sites-enabled as well:

sudo mv /etc/nginx/sites-enabled/onlyoffice /etc/nginx/sites-enabled/onlyoffice.bak

and run the previous steps again:

sudo mv /etc/nginx/sites-available/onlyoffice /etc/nginx/sites-available/onlyoffice.bak
wget http://download.onlyoffice.com/repo/debian/pool/main/o/onlyoffice-communityserver/onlyoffice-communityserver_12.8.0.1971_all.deb -O /tmp/onlyoffice-communityserver.deb
sudo apt install /tmp/onlyoffice-communityserver.deb -o Dpkg::Options::="--force-confmiss"

Please let us know the result.